/**
 *	@file	mainpage.h
 *	$Date:: 2022-11-10 14:54:20 +0900#$
 *	$Revision: 10 $
 *	$Author: iitsuka $
 *
 *	本ファイルは Doxygen の Main page 用ファイルであり、意味のあるコードは存在しない。
 *
 *	@mainpage
 *
 *	このモジュールを使用するためには、abaco純正のデバイスドライバ(rfm2g)を事前にインストールしておく必要がある。 @n
 *	また、本モジュールは CentOS 7.9(kernel 3.10.0-1160.el7.x86_64) + EPICS 3.15.8で動作を確認している。
 *
 *	- - -
 *	@par How to buid drvrm5565pci
 *	@li drvrm5565pci-YYMMDD.tar.gz を展開する。
 *	@code
 *	$ tar xzf drvrm5565pci-YYMMDD.tar.gz
 *	@endcode
 *	@li configure/RELEASE ファイルを編集して EPICS_BASE の定義を自環境に合わせて修正する。
 *	@code
 *	$ cd drvrm5565pci
 *	$ vi configure/RELEASE
 *	@endcode
 *	@code
 *					:
 *					:
 *	# EPICS_BASE should appear last so earlier modules can override stuff:
 *	EPICS_BASE = /opt/epics/R3-15-8/base  ← ここを修正する
 *					:
 *					:
 *	@endcode
 *	@li drvrm5565App/src/Makefile を編集して rfm2g のディレクトリ指定を自環境に合わせて修正する。 @n
 *	@code
 *					:
 *					:
 *	#----------------------------------------
 *	#  ADD RULES AFTER THIS LINE
 *	RELEASE_INCLUDES += -I/usr/lib64/rfm2g  ← ここを修正する
 *	@endcode
 *	@li make を行う。
 *	@code
 *	$ make
 *	@endcode
 *
 *	以上で完了。
 *
 *	- - -
 *	@par How to build IOC
 *	@li configure/RELEASE に drvrm5565pci モジュールをセットアップしたディレクトリの指定を追加する。 @n
 *	@code
 *	DRVRM5565 = $(EPICS_BASE)/../modules/drvrm5565pci  ← これを追加
 *	@endcode
 *	@li src/Makefile の <i>&lt;prod_name&gt;</i>_DBD に drvrm5565pci.dbd を追加する。 @n
 *	下記は <i>&lt;prod_name&gt;</i> がrmiocの場合の例である。
 *	@code
 *					:
 *					:
 *	#=============================
 *	# Build the IOC application
 *	
 *	PROD_IOC = rmioc
 *					・
 *					・
 *  # Include dbd files from all support applications:
 *	rmioc_DBD += drvrm5565pci.dbd    ← これを追加
 *					:
 *					:
 *	@endcode
 *	@li src/Makefile の <I>&lt;prod_name&gt;</i>_LIBS に drvrm5565pci を追加する。 @n
 *	下記は <i>&lt;prod_name&gt;</i> がrmiocの場合の例である。
 *	@code
 *					:
 *					:
 *	#=============================
 *	# Build the IOC application
 *	
 *	PROD_IOC = rmioc
 *					:
 *					:
 *	# Add all the support libraries needed by this IOC
 *	rmioc_LIBS += drvrm5565pci    ← これを追加
 *					:
 *					:
 *	@endcode
 *	@li src/Makefile の 最後に下記を追加する。 @n
 *	@code
 *					:
 *					:
 *	include $(TOP)/configure/RULES
 *	#----------------------------------------
 *	#  ADD RULES AFTER THIS LINE
 *	RELEASE_INCLUDES += -I/usr/lib64/rfm2g   ← これを追加
 *	PROD_DEPLIB_DIRS += /usr/lib64/rfm2g     ← これを追加
 *	EPICS_BASE_IOC_LIBS += rfm2g             ← これを追加
 *	@endcode
 *
 *	後は make を行えば完了。
 *
 *	- - -
 *	@par Function
 *	@li @ref hwerr "Support for Handling of error that was detected by hardware"@n
 *	@li @ref intrx "Support for Receiving Network-Interrupt"@n
 *	@li @ref inttx "Support for Transmitting Network-Interrupt"@n
 *	@li @ref aai "Support for Reading memory"@n
 *	@li @ref aao "Support for Writing memory"@n
 *	@li @ref iocshcmd "Provided iocsh command"
 */

/**
 *	@page hwerr Support for Handling of error that was detected by hardware
 *	- @subpage devsup_hwerr "Device Support"@n
 */

/**
 *	@page intrx Support for Receiving Network-Interrupt
 *	- @subpage recsup_intrx "Record Support"@n
 *	- @subpage devsup_intrx "Device Support"@n
 */

/**
 *	@page inttx Support for Transmitting Network-Interrupt
 *	- @subpage recsup_inttx "Record Support"@n
 *	- @subpage devsup_inttx "Device Support"@n
 */

/**
 *	@page aai Support for Reading memory
 *	- @subpage devsup_aai "Device Support"@n
 */

/**
 *	@page aao Support for Writing memory
 *	- @subpage devsup_aao "Device Support"@n
 */

/**
 *	@page iocshcmd Provided iocsh command
 *	- @subpage cmd_RM5565PciConfigure "RM5565PciConfigure"@n
 *	- @subpage cmd_RM5565DebugFlag "RM5565DebugFlag"@n
 */
